@@ -80,6 +80,8 @@ METHOD_LIST = {
     "bulk_delete": "add_",
 }
 
+SKIP_ENDPOINT = ["logout", "login", "revoke_token", "token"]
+
 class UserRolePermission(object):
     def __init__(self, get_response):
         self.get_response = get_response
@@ -89,69 +91,83 @@ class UserRolePermission(object):
         return self.get_response(request)
 
     def process_view(self, request, view_func, view_args, view_kwargs):
-        permission = ""
-        
+        SKIP_THIS = False
         try:
-            SETTINGS_METHOD = settings.ALLOWED_METHOD_PERMISSIONS
-            METHOD_LIST.update(SETTINGS_METHOD)
+            SKIP_ENDPOINT += settings.SKIP_ENDPOINT
         except:
             pass
 
         try:
-            show_permission_error = settings.SHOW_PERMISSION_ERROR
-        except:
-            show_permission_error = False
-
-        str_method = ''
-        try:
-            str_method = view_func.__dict__.get("actions").get(str(request.method).lower())
-            permission = (
-                METHOD_LIST.get(str_method)
-                + view_func.__module__.split(".")[-1]
-            )
-
+            requestURL = request.build_absolute_uri("?").split("/")[:-1][-1]
+            if requestURL in SKIP_ENDPOINT:
+                SKIP_THIS = True
         except:
             pass
 
-        token = request.META.get("HTTP_AUTHORIZATION", None)
-        if token:
-            token = token.split(" ")[1]
-
-        token_obj = AccessToken.objects.filter(token=token).select_related("user").first()
-        if token_obj:
-            if permission == "":
-                
-                message = 'Permission not matched.'
-
-                if show_permission_error:
-                    message += ' invalid permission -> ' + str_method
-
-                return JsonResponse(
-                    {
-                        "message": [message],
-                        "code": 400,
-                        "success": False,
-                        "data": {},
-                    },
-                    status=400,
-                )
+        if not SKIP_THIS:
+            permission = ""
+            
             try:
-                request_user = token_obj.user.role.permissions.filter(codename=permission)
+                SETTINGS_METHOD = settings.ALLOWED_METHOD_PERMISSIONS
+                METHOD_LIST.update(SETTINGS_METHOD)
             except:
-                request_user = token_obj.user.group.permissions.filter(codename=permission)
+                pass
 
-            if not request_user:
-                message = "You don't have access to perform this action."
+            try:
+                show_permission_error = settings.SHOW_PERMISSION_ERROR
+            except:
+                show_permission_error = False
 
-                if show_permission_error:
-                    message += ' invalid permission -> ' + str_method
-
-                return JsonResponse(
-                    {
-                        "message": [message],
-                        "code": 403,
-                        "success": False,
-                        "data": {},
-                    },
-                    status=403,
+            str_method = ''
+            try:
+                str_method = view_func.__dict__.get("actions").get(str(request.method).lower())
+                permission = (
+                    METHOD_LIST.get(str_method)
+                    + view_func.__module__.split(".")[-1]
                 )
+
+            except:
+                pass
+
+            token = request.META.get("HTTP_AUTHORIZATION", None)
+            if token:
+                token = token.split(" ")[1]
+
+            token_obj = AccessToken.objects.filter(token=token).select_related("user").first()
+            if token_obj:
+                if permission == "":
+                    
+                    message = 'Permission not matched.'
+
+                    if show_permission_error:
+                        message += ' invalid permission -> ' + str_method
+
+                    return JsonResponse(
+                        {
+                            "message": [message],
+                            "code": 400,
+                            "success": False,
+                            "data": {},
+                        },
+                        status=400,
+                    )
+                try:
+                    request_user = token_obj.user.role.permissions.filter(codename=permission)
+                except:
+                    request_user = token_obj.user.group.permissions.filter(codename=permission)
+
+                if not request_user:
+                    message = "You don't have access to perform this action."
+
+                    if show_permission_error:
+                        message += ' invalid permission -> ' + str_method
+
+                    return JsonResponse(
+                        {
+                            "message": [message],
+                            "code": 403,
+                            "success": False,
+                            "data": {},
+                        },
+                        status=403,
+                    )
